==> deverhood-react-1.16.51.tgz: package/src/query/form.js <==
const item = [
  `id`,
  `title`,
  `type`,
  `... on TextItem{
    isRequire
    tag
  }`,
  `
  ... on CheckboxItem{
    isRequire
    choices{
      value
      remark{
        type
        text
        tag
      }
      tag

    }
    isInline
  }`,
  `... on MultipleChoiceItem{
    isRequire
    choices{
      value
      remark{
        type
        text
        tag
      }
      tag

    }
    isInline
  }`,
  `... on DateItem{
    isRequire
    tag
  }`,
  `... on TimeItem{
    isRequire
  }`,
  `... on DateTimeItem{
    isRequire
  }`,
  `... on ScaleItem{
    isRequire
    lowerBound
    upperBound
    points
    step
    tag
  }`,
  // isMultipleChoice
  `... on CheckboxGridItem{
    isRequire
    rows
    columns{
      value
      tag
    }
  }`,
  `... on GridItem{
    isRequire
    rows
    columns{
      value
      tag
    }
  }`,
  `... on DropdownItem{
    isRequire
    choices{
      value
      remark{
        type
        text
        tag
      }
      tag
    }
  }`,
  `... on ListItem{
    isRequire
  }`
];
export default {
  list: [
    `id`,
    `title`,
    `description`,
    `evaluations(size:1000){
      id
      name
      description
    }`
  ],
  item: item,
  data: [
    `id`,
    `title`,
    `description`,
    `specialtyId`,
    `majorId`,
    `tags`,
    `items(size:1000){
      ${item.map(v => v)}
    }`,
    `evaluations(size:1000){
      id
      name,
      description
    }`
  ],
  TEXT: [`id`, `title`, `type`, `isRequire`, `tag`],
  LIST: [`id`, `title`, `type`, `isRequire`],
  DATE: [`id`, `title`, `type`, `isRequire`, `tag`],
  DATETIME: [`id`, `title`, `type`, `isRequire`],
  TIME: [`id`, `title`, `type`, `isRequire`],
  CHECKBOX: [
    `id`,
    `title`,
    `type`,
    `isRequire`,
    `choices{
    value
    remark{
      type
      text
      tag
    }
    tag
  }`,
    `isInline`
  ],
  MULTIPLE_CHOICE: [
    `id`,
    `title`,
    `type`,
    `isRequire`,
    `choices{
    value
    remark{
      type
      text
      tag
    }
    tag

  }`,
    `isInline`
  ],
  DROPDOWN: [
    `id`,
    `title`,
    `type`,
    `isRequire`,
    `choices{
    value
    remark{
      type
      text
      tag
    }
    tag
  }`
  ],
  SCALE: [
    `id`,
    `title`,
    `type`,
    `isRequire`,
    `lowerBound`,
    `upperBound`,
    `points`,
    `step`,
    `tag`,
    `isMultipleChoice`
  ],
  CHECKBOX_GRID: [
    `id`,
    `title`,
    `type`,
    `isRequire`,
    `rows`,
    `columns{value tag}`
  ],
  GRID: [`id`, `title`, `type`, `isRequire`, `rows`, `columns{value tag}`],
  SECTION_HEADER: [`id`, `title`, `type`],
  response: [
    `id`,
    `formId`,
    `itemResponses{
      id {
        itemId
        formResponseId
      }
    response
    }`
  ],
  responses: [
    `id`,
    `form{
      id
      title
    }`,
    `requestUser{
      username
      titleTh
      firstNameTh
      lastNameTh
    }`,
    `responseUser{
      username
      titleTh
      firstNameTh
      lastNameTh
    }`,
    `instituteId`,
    `score`,
    `updatedOn`,
    `status`
  ],
  item: [
    `id {
      itemId
      formResponseId
    }`,
    `response`
  ],
  stat: [
    `status {
      status
      count
    }`,
    `form{
      title
      id
    }`
  ],
  equations: [`id`, `name`, `description`],
  equation: [
    `id`,
    `name`,
    `description`,
    `conditions{
        id
        name
        description
        expression
        result
        color
      }`,
    `value`
  ],
  condition: [`name`, `description`, `expression`, `result`, `color`, `id`],
  stats: [
    `evaluation{
      name
    }`,
    `evals{
    start
    end
    count
    countTrue
    average
  }`
  ]
};

==> deverhood-react-1.16.59.tgz: package/src/query/form.js <==
const item = [
  `id`,
  `title`,
  `type`,
  `... on TextItem{
    isRequire
    tag
  }`,
  `
  ... on CheckboxItem{
    isRequire
    choices{
      value
      remark{
        type
        text
        tag
      }
      tag

    }
    isInline
  }`,
  `... on MultipleChoiceItem{
    isRequire
    choices{
      value
      remark{
        type
        text
        tag
      }
      tag

    }
    isInline
  }`,
  `... on DateItem{
    isRequire
    tag
  }`,
  `... on TimeItem{
    isRequire
  }`,
  `... on DateTimeItem{
    isRequire
  }`,
  `... on ScaleItem{
    isRequire
    lowerBound
    upperBound
    points
    step
    tag
    isMultipleChoice
  }`,
  `... on CheckboxGridItem{
    isRequire
    rows{
      value
      tag
    }
    columns{
      value
      tag
    }
  }`,
  `... on GridItem{
    isRequire
    rows{
      value
      tag
    }
    columns{
      value
      tag
    }
  }`,
  `... on DropdownItem{
    isRequire
    choices{
      value
      remark{
        type
        text
        tag
      }
      tag
    }
  }`,
  `... on ListItem{
    isRequire
  }`
];
export default {
  list: [
    `id`,
    `title`,
    `description`,
    `requireInstitute`,
    `evaluations(size:1000){
      id
      name
      description

    }`
  ],
  item: item,
  data: [
    `id`,
    `title`,
    `description`,
    `specialtyId`,
    `majorId`,
    `tags`,
    `files{
      id
      name
      size
    }`,
    `fileIds`,
    `items(size:1000){
      ${item.map(v => v)}
    }`,
    `evaluations(size:1000){
      id
      name,
      description
    }`
  ],
  TEXT: [`id`, `title`, `type`, `isRequire`, `tag`],
  LIST: [`id`, `title`, `type`, `isRequire`],
  DATE: [`id`, `title`, `type`, `isRequire`, `tag`],
  DATETIME: [`id`, `title`, `type`, `isRequire`],
  TIME: [`id`, `title`, `type`, `isRequire`],
  CHECKBOX: [
    `id`,
    `title`,
    `type`,
    `isRequire`,
    `choices{
    value
    remark{
      type
      text
      tag
    }
    tag
  }`,
    `isInline`
  ],
  MULTIPLE_CHOICE: [
    `id`,
    `title`,
    `type`,
    `isRequire`,
    `choices{
    value
    remark{
      type
      text
      tag
    }
    tag

  }`,
    `isInline`
  ],
  DROPDOWN: [
    `id`,
    `title`,
    `type`,
    `isRequire`,
    `choices{
    value
    remark{
      type
      text
      tag
    }
    tag
  }`
  ],
  SCALE: [
    `id`,
    `title`,
    `type`,
    `isRequire`,
    `lowerBound`,
    `upperBound`,
    `points`,
    `step`,
    `tag`,
    `isMultipleChoice`
  ],
  CHECKBOX_GRID: [`id`, `title`, `type`, `isRequire`, `columns{value tag}`],
  GRID: [`id`, `title`, `type`, `isRequire`, `columns{value tag}`],
  SECTION_HEADER: [`id`, `title`, `type`],
  response: [
    `id`,
    `formId`,
    `form{
      id
      items(size:1000){
        ${item.map(v => v)}
      }
    }`,
    `responseUser{
      username
      firstNameTh
      lastNameTh
    }`,
    `requestUser{
      username
      firstNameTh
      lastNameTh
    }`,
    `createdOn`,
    `itemResponses{
        id {
          itemId
          formResponseId
        }
      response,
      }`,
    `evaluations {
      id
      name
      eval2
    }`,
    `status`,
    `specialtyId`,
    `instituteId`
  ],
  responses: [
    `id`,
    `form{
      id
      title
    }`,
    `requestUser{
      username
      titleTh
      firstNameTh
      lastNameTh
    }`,
    `responseUser{
      username
      titleTh
      firstNameTh
      lastNameTh
    }`,
    `instituteId`,
    `score`,
    `updatedOn`,
    `status`,
    `evaluations {
      id
      name
      eval2
    }`
  ],
  item: [
    `id {
      itemId
      formResponseId
    }`,
    `response`
  ],
  stat: [
    `status {
      status
      count
    }`,
    `form{
      title
      id
    }`
  ],
  equations: [`id`, `name`, `description`],
  equation: [
    `id`,
    `name`,
    `description`,
    `conditions{
        id
        name
        description
        expression
        result
        color
      }`,
    `value`
  ],
  condition: [`name`, `description`, `expression`, `result`, `color`, `id`],
  stats: [
    `formId`,
    `status{
      status
      count
    }`,
    `form{
      id
      title
    }`
  ],
  reponsed_student: [
    `form{
      title
    }`,
    `responseUser{
      username
      firstNameTh
      lastNameTh
    }`,
    `requestUser{
      username
      firstNameTh
      lastNameTh
    }`
  ]
};
